import threading
from loguru import logger
from time import sleep
from DataObject import DataObject
from enum import Enum


POISON_PILL = DataObject(name="PoisonPill", topic="kill", payload=None)

class e_State(Enum):
    IDLE = 0
    RUNNING = 1

class RigCmdHandler(threading.Thread):
    def __init__(self, config, inQueue):
        super().__init__()

        self.config = config
        self.inQueue = inQueue
        self.state = e_State.IDLE

    def run(self):
        logger.debug("RigCmdHandler loop started")
        while True:
            dataObject = self.inQueue.get()
            if (dataObject == POISON_PILL):
                logger.error("RigCmdHandler swallowed the poison pill")
                break
            
            logger.info(f"State is {self.state}")
            # Python 3.10 is required!!
            match self.state:
                case e_State.IDLE:
                    if (dataObject.name == 'cmd') and (dataObject.payload["es"] == 'start'):
                        logger.info("start command received, switch to RUNNING state")
                        self.state = e_State.RUNNING
                    elif (dataObject.name == 'cmd'):
                        logger.error(f"illegal command {dataObject.name} received in IDLE state")
                    else:
                        logger.error("illegal message received in IDLE state")
                case e_State.RUNNING:
                    if (dataObject.name == 'cmd') and (dataObject.payload["es"] == 'stop'):
                        logger.info("stop command received, switch to IDLE state")
                        self.state = e_State.IDLE
                    elif (dataObject.name == 'cmd'):
                        logger.error(f"illegal command {dataObject.name} received in RUNNING state")
                    else:
                        logger.error("illegal message received in RUNNING state")


    def stop(self):
        self.inQueue.put(POISON_PILL)
        logger.debug("kill flag set")
